
#ifndef __SELECTION_H__
#define __SELECTION_H__

#include "defs.h"

void            selection_toggled(GtkToggleButton *togglebutton, gpointer data);
void            selection_lookup_start();
void            selection_lookup_stop();
void            selection_lookup_suspend();
void            selection_lookup_resume();
void		selection_search_in_mainwnd();
void		selection_search_in_popupwnd();

struct _selection
{
    gboolean    lookup_started, lookup_suspended;
    glong       maxchar;
    guint       timeout_id;
} selection;

#endif /* __SELECTION_H__ */
